@@ -19,6 +19,7 @@
 #include <QTextStream>
 #include <QVBoxLayout>
 
+#include <kwidgetsaddons_version.h>
 #include <KLocalizedString>
 #include <KGuiItem>
 #include <KMessageBox>
@@ -31,7 +32,7 @@ KGrNHDialog::KGrNHDialog (const QString & levelName, const QString & levelHint,
                         QWidget * parent)
                 : QDialog (parent)
 {
-    setWindowTitle (i18n ("Edit Name & Hint"));
+    setWindowTitle (i18nc("@title:window", "Edit Name or Hint"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -100,7 +101,7 @@ KGrECDialog::KGrECDialog (int action, int gameIndex,
     myGameList  = gamesList;
     defaultGame  = gameIndex;
 
-    setWindowTitle (i18n ("Edit Game Info"));
+    setWindowTitle (i18nc("@title:window", "Edit Game Info"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
 
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KGrECDialog::accept);
@@ -166,10 +167,10 @@ KGrECDialog::KGrECDialog (int action, int gameIndex,
     dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-1)*cell);
 
     if (action == SL_CR_GAME) {
-         setWindowTitle (i18n ("Create Game"));
+         setWindowTitle (i18nc("@title:window", "Create Game"));
     }
     else {
-         setWindowTitle (i18n ("Edit Game Info"));
+         setWindowTitle (i18nc("@title:window", "Edit Game Info"));
     }
 
     QString OKText;
@@ -244,7 +245,7 @@ KGrLGDialog::KGrLGDialog (QFile * savedGames,
                           QWidget * parent)
                 : QDialog (parent)
 {
-    setWindowTitle (i18n ("Select Saved Game"));
+    setWindowTitle (i18nc("@title:window", "Select Saved Game"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -339,24 +340,40 @@ int KGrMessage::warning (QWidget * parent, const QString &caption,
                         const QString &label1, const QString &label2)
 {
     // KDE does word-wrapping and will observe "\n" line-breaks.
-    int ans = 0;
+    int result = 0;
     if (label2.isEmpty()) {
         // Display a box with 2 buttons.
-        ans = KMessageBox::questionYesNo (parent, text, caption,
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        KMessageBox::ButtonCode ans = KMessageBox::questionTwoActions (parent, text, caption,
+#else
+        KMessageBox::ButtonCode ans = KMessageBox::questionYesNo (parent, text, caption,
+#endif
                             KGuiItem (label0), KGuiItem (label1));
-        ans = (ans == KMessageBox::Yes) ? 0 : 1;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        result = (ans == KMessageBox::PrimaryAction) ? 0 : 1;
+#else
+        result = (ans == KMessageBox::Yes) ? 0 : 1;
+#endif
     }
     else {
         // Display a box with 3 buttons.
-        ans = KMessageBox::questionYesNoCancel (parent, text, caption,
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        KMessageBox::ButtonCode ans = KMessageBox::questionTwoActionsCancel (parent, text, caption,
+#else
+        KMessageBox::ButtonCode ans = KMessageBox::questionYesNoCancel (parent, text, caption,
+#endif
                             KGuiItem (label0), KGuiItem (label1),
                             KGuiItem (label2));
         if (ans == KMessageBox::Cancel)
-            ans = 2;
+            result = 2;
         else
-            ans = (ans == KMessageBox::Yes) ? 0 : 1;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            result = (ans == KMessageBox::PrimaryAction) ? 0 : 1;
+#else
+            result = (ans == KMessageBox::Yes) ? 0 : 1;
+#endif
     }
-    return (ans);
+    return (result);
 }
 
 
